[nautilus-actions] Rename na_object_check_edition_status() to na_object_check_status()



commit 7eca51ec919fcd4184baa69f93e07c64adc1932a
Author: Pierre Wieser <pwieser trychlos org>
Date:   Tue Oct 13 22:31:59 2009 +0200

    Rename na_object_check_edition_status() to na_object_check_status()

 ChangeLog                     |   12 ++++++++++++
 src/nact/nact-iactions-list.c |    6 +++---
 src/nact/nact-main-menubar.c  |    4 ++--
 src/nact/nact-tree-model.c    |    4 ++--
 src/runtime/na-iduplicable.c  |    8 ++++----
 src/runtime/na-iduplicable.h  |    2 +-
 src/runtime/na-iio-provider.c |    2 +-
 src/runtime/na-object-api.h   |    2 +-
 src/runtime/na-object-fn.h    |    2 +-
 src/runtime/na-object-item.c  |    2 +-
 src/runtime/na-object.c       |   16 ++++++++--------
 11 files changed, 36 insertions(+), 24 deletions(-)
---
diff --git a/ChangeLog b/ChangeLog
index d562839..d803be4 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,17 @@
 2009-10-13 Pierre Wieser <pwieser trychlos org>
 
+	* src/nact/nact-iactions-list.c:
+	* src/nact/nact-main-menubar.c:
+	* src/nact/nact-tree-model.c:
+	* src/runtime/na-iduplicable.c:
+	* src/runtime/na-iduplicable.h:
+	* src/runtime/na-iio-provider.c:
+	* src/runtime/na-object-api.h:
+	* src/runtime/na-object-fn.h:
+	* src/runtime/na-object-item.c:
+	* src/runtime/na-object.c:
+	Renamed na_object_check_edition_status() to na_object_check_status().
+
 	* src/common/na-object-api.h (na_object_get_topmost_parent):
 	New function.
 
diff --git a/src/nact/nact-iactions-list.c b/src/nact/nact-iactions-list.c
index 57b29dd..a32d421 100644
--- a/src/nact/nact-iactions-list.c
+++ b/src/nact/nact-iactions-list.c
@@ -1145,7 +1145,7 @@ nact_iactions_list_insert_into( NactIActionsList *instance, GList *items )
 
 		parent = do_insert_into_first( treeview, model, items, insert_path, &new_path );
 
-		na_object_check_edition_status( parent );
+		na_object_check_status( parent );
 
 		gtk_tree_model_filter_refilter( GTK_TREE_MODEL_FILTER( model ));
 
@@ -1311,7 +1311,7 @@ update_parents_edition_status( GList *parents, GList *items )
 	}*/
 
 	for( it = parents ; it ; it = it->next ){
-		na_object_check_edition_status( it->data );
+		na_object_check_status( it->data );
 	}
 
 	g_list_free( parents );
@@ -1935,7 +1935,7 @@ on_tab_updatable_item_updated( NactIActionsList *instance, NAObject *object )
 		treeview = get_actions_list_treeview( instance );
 		model = gtk_tree_view_get_model( treeview );
 		item = na_object_get_topmost_parent( object );
-		na_object_check_edition_status( item );
+		na_object_check_status( item );
 	}
 }
 
diff --git a/src/nact/nact-main-menubar.c b/src/nact/nact-main-menubar.c
index 120b9b1..34e0b61 100644
--- a/src/nact/nact-main-menubar.c
+++ b/src/nact/nact-main-menubar.c
@@ -639,7 +639,7 @@ on_new_profile_activated( GtkAction *gtk_action, NactMainWindow *window )
 	name = na_object_action_get_new_profile_name( action );
 	na_object_set_parent( profile, action );
 	na_object_set_id( profile, name );
-	na_object_check_edition_status( profile );
+	na_object_check_status( profile );
 
 	items = g_list_prepend( NULL, profile );
 	nact_iactions_list_insert_items( NACT_IACTIONS_LIST( window ), items, NULL );
@@ -751,7 +751,7 @@ save_item( NactMainWindow *window, NAPivot *pivot, NAObjectItem *item )
 			na_object_reset_origin( item, dup_pivot );
 			na_pivot_add_item( pivot, NA_OBJECT( dup_pivot ));
 
-			na_object_check_edition_status( item );
+			na_object_check_status( item );
 		}
 	}
 }
diff --git a/src/nact/nact-tree-model.c b/src/nact/nact-tree-model.c
index 1d8b6de..e7847f3 100644
--- a/src/nact/nact-tree-model.c
+++ b/src/nact/nact-tree-model.c
@@ -677,7 +677,7 @@ nact_tree_model_fill( NactTreeModel *model, GList *items, gboolean only_actions)
 
 		for( it = items ; it ; it = it->next ){
 			duplicate = na_object_duplicate( it->data );
-			na_object_check_edition_status( duplicate );
+			na_object_check_status( duplicate );
 			fill_tree_store( ts_model, model->private->treeview, duplicate, only_actions, NULL );
 			na_object_unref( duplicate );
 		}
@@ -971,7 +971,7 @@ nact_tree_model_remove( NactTreeModel *model, NAObject *object )
 		}
 
 		for( it = parents ; it ; it = it->next ){
-			na_object_check_edition_status( it->data );
+			na_object_check_status( it->data );
 		}
 	}
 
diff --git a/src/runtime/na-iduplicable.h b/src/runtime/na-iduplicable.h
index b390a6f..38d83e2 100644
--- a/src/runtime/na-iduplicable.h
+++ b/src/runtime/na-iduplicable.h
@@ -152,7 +152,7 @@ GType          na_iduplicable_get_type( void );
 void           na_iduplicable_init( NAIDuplicable *object );
 void           na_iduplicable_dispose( NAIDuplicable *object );
 void           na_iduplicable_dump( const NAIDuplicable *object );
-void           na_iduplicable_check_edition_status( const NAIDuplicable *object );
+void           na_iduplicable_check_status( const NAIDuplicable *object );
 NAIDuplicable *na_iduplicable_duplicate( const NAIDuplicable *object );
 
 gboolean       na_iduplicable_is_modified( const NAIDuplicable *object );
diff --git a/src/runtime/na-iio-provider.c b/src/runtime/na-iio-provider.c
index 87e78bf..0ab080d 100644
--- a/src/runtime/na-iio-provider.c
+++ b/src/runtime/na-iio-provider.c
@@ -211,7 +211,7 @@ na_iio_provider_get_items_tree( const NAPivot *pivot )
 		}
 
 		for( it = hierarchy ; it ; it = it->next ){
-			na_object_check_edition_status( it->data );
+			na_object_check_status( it->data );
 		}
 	}
 
diff --git a/src/runtime/na-object-api.h b/src/runtime/na-object-api.h
index d30e9ae..1ea604f 100644
--- a/src/runtime/na-object-api.h
+++ b/src/runtime/na-object-api.h
@@ -64,7 +64,7 @@ G_BEGIN_DECLS
 
 /* NAIDuplicable
  */
-#define na_object_check_edition_status( object )	na_object_iduplicable_check_edition_status( NA_OBJECT( object ))
+#define na_object_check_status( object )			na_object_iduplicable_check_status( NA_OBJECT( object ))
 #define na_object_duplicate( object )				na_object_iduplicable_duplicate( NA_OBJECT( object ))
 #define na_object_are_equal( a, b )					na_object_iduplicable_are_equal( NA_OBJECT( a ), NA_OBJECT( b ))
 #define na_object_is_modified( object )				na_object_iduplicable_is_modified( NA_OBJECT( object ))
diff --git a/src/runtime/na-object-fn.h b/src/runtime/na-object-fn.h
index a96160d..e5971b6 100644
--- a/src/runtime/na-object-fn.h
+++ b/src/runtime/na-object-fn.h
@@ -48,7 +48,7 @@ G_BEGIN_DECLS
 
 /* NAIDuplicable
  */
-void      na_object_iduplicable_check_edition_status( const NAObject *object );
+void      na_object_iduplicable_check_status( const NAObject *object );
 NAObject *na_object_iduplicable_duplicate( const NAObject *object );
 gboolean  na_object_iduplicable_are_equal( const NAObject *a, const NAObject *b );
 gboolean  na_object_iduplicable_is_modified( const NAObject *object );
diff --git a/src/runtime/na-object-item.c b/src/runtime/na-object-item.c
index d564b9e..b37aa30 100644
--- a/src/runtime/na-object-item.c
+++ b/src/runtime/na-object-item.c
@@ -819,7 +819,7 @@ object_copy( NAObject *target, const NAObject *source )
  * because the equality test will stop as soon as it fails, and we so
  * cannot be sure to even come here.
  *
- * The recursivity of na_object_check_edition_status() is directly
+ * The recursivity of na_object_check_status() is directly
  * dealt with by the main entry api function.
  *
  * More, the modification status of subitems doesn't have any
diff --git a/src/runtime/na-object.c b/src/runtime/na-object.c
index 40195ff..a5e3779 100644
--- a/src/runtime/na-object.c
+++ b/src/runtime/na-object.c
@@ -231,7 +231,7 @@ instance_finalize( GObject *object )
 }
 
 /**
- * na_object_iduplicable_check_edition_status:
+ * na_object_iduplicable_check_status:
  * @object: the #NAObject object to be checked.
  *
  * Recursively checks for the edition status of @object and its childs
@@ -240,8 +240,8 @@ instance_finalize( GObject *object )
  * Internally set some properties which may be requested later. This
  * two-steps check-request let us optimize some work in the UI.
  *
- * na_object_check_edition_status( object )
- *  +- na_iduplicable_check_edition_status( object )
+ * na_object_check_status( object )
+ *  +- na_iduplicable_check_status( object )
  *      +- get_origin( object )
  *      +- modified_status = v_are_equal( origin, object ) -> interface are_equal()
  *      +- valid_status = v_is_valid( object )             -> interface is_valid()
@@ -250,12 +250,12 @@ instance_finalize( GObject *object )
  * that edition status of childs is actually checked.
  */
 void
-na_object_iduplicable_check_edition_status( const NAObject *object )
+na_object_iduplicable_check_status( const NAObject *object )
 {
 	GList *childs, *ic;
 
 #if NA_IDUPLICABLE_EDITION_STATUS_DEBUG
-	g_debug( "na_object_iduplicable_check_edition_status: object=%p (%s)",
+	g_debug( "na_object_iduplicable_check_status: object=%p (%s)",
 			( void * ) object, G_OBJECT_TYPE_NAME( object ));
 #endif
 	g_return_if_fail( NA_IS_OBJECT( object ));
@@ -264,10 +264,10 @@ na_object_iduplicable_check_edition_status( const NAObject *object )
 
 		childs = v_get_childs( object );
 		for( ic = childs ; ic ; ic = ic->next ){
-			na_object_iduplicable_check_edition_status( NA_OBJECT( ic->data ));
+			na_object_iduplicable_check_status( NA_OBJECT( ic->data ));
 		}
 
-		na_iduplicable_check_edition_status( NA_IDUPLICABLE( object ));
+		na_iduplicable_check_status( NA_IDUPLICABLE( object ));
 	}
 }
 
@@ -359,7 +359,7 @@ na_object_iduplicable_are_equal( const NAObject *a, const NAObject *b )
  * to get benefits provided by the IDuplicable interface.
  *
  * This suppose also that the edition status of @object has previously
- * been checked via na_object_check_edition_status().
+ * been checked via na_object_check_status().
  *
  * Returns: %TRUE is the provided object has been modified regarding to
  * the original one, %FALSE else.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/runtime/na-iduplicable.c b/src/runtime/na-iduplicable.c
index 7414481..41d6727 100644
--- a/src/runtime/na-iduplicable.c
+++ b/src/runtime/na-iduplicable.c
@@ -301,7 +301,7 @@ na_iduplicable_dump( const NAIDuplicable *object )
 }
 
 /**
- * na_iduplicable_check_edition_status:
+ * na_iduplicable_check_status:
  * @object: the #NAIDuplicable object to be checked.
  *
  * Checks the edition status of the #NAIDuplicable object, and set up
@@ -313,17 +313,17 @@ na_iduplicable_dump( const NAIDuplicable *object )
  * functions na_iduplicable_is_modified() and na_iduplicable_is_valid()
  * will then only return the current value of the properties.
  *
  * na_iduplicable_check_edition_status() is not, as itself, recursive.
  * That is, the modification and validity status are only set on the
  * specified object.
  * Nonetheless, a derived class may perfectly implement a recursive
  * check on childs, if any. See, e.g. #NAObject implementation.
  */
 void
-na_iduplicable_check_edition_status( const NAIDuplicable *object )
+na_iduplicable_check_status( const NAIDuplicable *object )
 {
 #if NA_IDUPLICABLE_EDITION_STATUS_DEBUG
-	static const gchar *thisfn = "na_iduplicable_check_edition_status";
+	static const gchar *thisfn = "na_iduplicable_check_status";
 #endif
 	gboolean modified = TRUE;
 	NAIDuplicable *origin;
@@ -313,17 +313,17 @@ na_iduplicable_dump( const NAIDuplicable *object )
  * will then only return the current value of the properties.
  *
- * na_iduplicable_check_edition_status() is not, as itself, recursive.
+ * na_iduplicable_check_status() is not, as itself, recursive.
  * That is, the modification and validity status are only set on the
  * specified object.